@@ -72,6 +72,9 @@ const DEFAULT_UNKNOWN_OBJECTS_POLICY: FilterPolicy = FilterPolicy::Warn;
 /// The default maximum object size.
 const DEFAULT_MAX_OBJECT_SIZE: u64 = 20_000_000;
 
+/// The default maximum CA depth.
+const DEFAULT_MAX_CA_DEPTH: usize = 32;
+
 
 //------------ Config --------------------------------------------------------  
 
@@ -203,13 +206,13 @@ pub struct Config {
     /// Should we keep RRDP responses and if so where?
     pub rrdp_keep_responses: Option<PathBuf>,
 
-    /// Disable the use if the gzip transfer encoding in the RRDP client.
-    pub rrdp_disable_gzip: bool,
-
     /// Optional size limit for objects.
     pub max_object_size: Option<u64>,
 
-    /// Wether to not cleanup the repository directory after a validation run.
+    /// Maxium length of the CA chain.
+    pub max_ca_depth: usize,
+
+    /// Whether to not cleanup the repository directory after a validation run.
     ///
     /// If this is `false` and update has not been disabled otherwise, all
     /// data for rsync modules (if rsync is enabled) and RRDP servers (if
@@ -421,9 +424,10 @@ impl Config {
             .help("Keep RRDP responses in the given directory")
             .takes_value(true)
         )
+        // XXX Remove in next breaking release
         .arg(Arg::with_name("rrdp-disable-gzip")
             .long("rrdp-disable-gzip")
-            .help("Disable the gzip transfer encoding in RRDP")
+            .hidden(true)
         )
         .arg(Arg::with_name("max-object-size")
             .long("max-object-size")
@@ -753,11 +757,6 @@ impl Config {
             self.rrdp_keep_responses = Some(path.into())
         }
 
-        // rrdp_disable_gzip
-        if matches.is_present("rrdp-disable-gzip") {
-            self.rrdp_disable_gzip = true;
-        }
-
         // max_object_size
         if let Some(value) = from_str_value_of(matches, "max-object-size")? {
             if value == 0 {
@@ -768,6 +767,11 @@ impl Config {
             }
         }
 
+        // max_ca_depth
+        if let Some(value) = from_str_value_of(matches, "max-ca-depth")? {
+            self.max_ca_depth = value;
+        }
+
         // dirty_repository
         if matches.is_present("dirty-repository") {
             self.dirty_repository = true
@@ -1064,9 +1068,6 @@ impl Config {
             },
             rrdp_user_agent: DEFAULT_RRDP_USER_AGENT.to_string(),
             rrdp_keep_responses: file.take_path("rrdp-keep-responses")?,
-            rrdp_disable_gzip: {
-                file.take_bool("rrdp-disable-gzip")?.unwrap_or(false)
-            },
             max_object_size: {
                 match file.take_u64("max-object-size")? {
                     Some(0) => None,
@@ -1074,6 +1075,10 @@ impl Config {
                     None => Some(DEFAULT_MAX_OBJECT_SIZE),
                 }
             },
+            max_ca_depth: {
+                file.take_usize("max-ca-depth")?
+                    .unwrap_or(DEFAULT_MAX_CA_DEPTH)
+            },
             dirty_repository: file.take_bool("dirty")?.unwrap_or(false),
             validation_threads: {
                 file.take_small_usize("validation-threads")?
@@ -1128,6 +1133,10 @@ impl Config {
             group: file.take_string("group")?,
             tal_labels: file.take_string_map("tal-labels")?.unwrap_or_default(),
         };
+        
+        // XXX Remove in next breaking release.
+        let _ = file.take_bool("rrdp-disable-gzip")?;
+
         file.check_exhausted()?;
         Ok(res)
     }
@@ -1247,8 +1256,8 @@ impl Config {
             rrdp_proxies: Vec::new(),
             rrdp_user_agent: DEFAULT_RRDP_USER_AGENT.to_string(),
             rrdp_keep_responses: None,
-            rrdp_disable_gzip: false,
             max_object_size: Some(DEFAULT_MAX_OBJECT_SIZE),
+            max_ca_depth: DEFAULT_MAX_CA_DEPTH,
             dirty_repository: DEFAULT_DIRTY_REPOSITORY,
             validation_threads: ::num_cpus::get(),
             refresh: Duration::from_secs(DEFAULT_REFRESH),
@@ -1426,18 +1435,15 @@ impl Config {
                 format!("{}", path.display()).into()
             );
         }
-        if self.rrdp_disable_gzip {
-            res.insert(
-                "rrdp-disable-gzip".into(),
-                true.into()
-            );
-        }
         res.insert("max-object-size".into(),
             match self.max_object_size {
                 Some(value) => value as i64,
                 None => 0,
             }.into()
         );
+        res.insert("max-ca-depth".into(),
+            (self.max_ca_depth as i64).into()
+        );
         res.insert("dirty".into(), self.dirty_repository.into());
         res.insert(
             "validation-threads".into(),
@@ -2334,7 +2340,7 @@ mod test {
         assert_eq!(config.history_size, DEFAULT_HISTORY_SIZE);
         assert!(config.rtr_listen.is_empty());
         assert!(config.http_listen.is_empty());
-        assert_eq!(config.systemd_listen, false);
+        assert!(!config.systemd_listen);
         assert_eq!(config.log_level, LevelFilter::Warn);
         assert_eq!(config.log_target, LogTarget::Default(Facility::LOG_DAEMON));
     }
@@ -2358,7 +2364,7 @@ mod test {
              log-level = \"info\"\n\
              log = \"file\"\n\
              log-file = \"foo.log\"",
-            &Path::new("/test/routinator.conf")
+            Path::new("/test/routinator.conf")
         ).unwrap();
         let config = Config::from_config_file(config).unwrap();
         assert_eq!(config.cache_dir.to_str().unwrap(), "/repodir");
@@ -2367,7 +2373,7 @@ mod test {
             config.exceptions,
             vec![PathBuf::from("/test/ex1"), PathBuf::from("/ex2")]
         );
-        assert_eq!(config.strict, true);
+        assert!(config.strict);
         assert_eq!(config.validation_threads, 1000);
         assert_eq!(config.refresh, Duration::from_secs(6));
         assert_eq!(config.retry, Duration::from_secs(7));
@@ -2384,7 +2390,7 @@ mod test {
             config.http_listen,
             vec![SocketAddr::from_str("192.0.2.4:8080").unwrap()]
         );
-        assert_eq!(config.systemd_listen, true);
+        assert!(config.systemd_listen);
         assert_eq!(config.log_level, LevelFilter::Info);
         assert_eq!(
             config.log_target,
@@ -2398,13 +2404,13 @@ mod test {
         let config = ConfigFile::parse(
             "repository-dir = \"/repodir\"\n\
              tal-dir = \"taldir\"",
-            &Path::new("/test/routinator.conf")
+            Path::new("/test/routinator.conf")
         ).unwrap();
         let config = Config::from_config_file(config).unwrap();
         assert_eq!(config.cache_dir.to_str().unwrap(), "/repodir");
         assert_eq!(config.tal_dir.to_str().unwrap(), "/test/taldir");
         assert!(config.exceptions.is_empty());
-        assert_eq!(config.strict, false);
+        assert!(!config.strict);
         assert_eq!(config.validation_threads, ::num_cpus::get());
         assert_eq!(config.refresh, Duration::from_secs(DEFAULT_REFRESH));
         assert_eq!(config.retry, Duration::from_secs(DEFAULT_RETRY));
@@ -2412,7 +2418,7 @@ mod test {
         assert_eq!(config.history_size, DEFAULT_HISTORY_SIZE);
         assert!(config.rtr_listen.is_empty());
         assert!(config.http_listen.is_empty());
-        assert_eq!(config.systemd_listen, false);
+        assert!(!config.systemd_listen);
         assert!(config.http_listen.is_empty());
         assert_eq!(config.log_level, LevelFilter::Warn);
         assert_eq!(
@@ -2464,7 +2470,7 @@ mod test {
         assert_eq!(
             config.exceptions, [Path::new("/x1"), Path::new("/test/x2")]
         );
-        assert_eq!(config.strict, true);
+        assert!(config.strict);
         assert_eq!(config.validation_threads, 2000);
         assert_eq!(config.log_target, LogTarget::Syslog(Facility::LOG_AUTH));
     }
@@ -2508,7 +2514,7 @@ mod test {
             config.http_listen,
             vec![SocketAddr::from_str("192.0.2.4:8080").unwrap()]
         );
-        assert_eq!(config.systemd_listen, true);
+        assert!(config.systemd_listen);
     }
 }
 
